@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: open.c,v 1.24 2004/11/28 01:32:55 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -27,29 +25,35 @@
 #include <glibtop/cpu.h>
 #include <glibtop/open.h>
 
+#include "glibtop_private.h"
+
 /* =====================================================
  * Linux kernel version information for procps utilities
  * Copyright (c) 1996 Charles Blake <cblake@bbn.com>
  */
 #include <sys/utsname.h>
 
-#define LINUX_VERSION(x,y,z)   (0x10000*(x) + 0x100*(y) + z)
+static unsigned get_linux_version(void) {
 
-static int linux_version_code = 0;
+    static unsigned linux_version_code = 0;
 
-static void set_linux_version(void) {
-    static struct utsname uts;
-    int x = 0, y = 0, z = 0;	/* cleared in case sscanf() < 3 */
-    
-    if (linux_version_code) return;
-    if (uname(&uts) == -1)	/* failure most likely implies impending death */
-	exit(1);
-    if (sscanf(uts.release, "%d.%d.%d", &x, &y, &z) < 3)
-	fprintf(stderr,		/* *very* unlikely to happen by accident */
-		"Non-standard uts for running kernel:\n"
-		"release %s=%d.%d.%d gives version code %d\n",
-		uts.release, x, y, z, LINUX_VERSION(x,y,z));
-    linux_version_code = LINUX_VERSION(x, y, z);
+    if(!linux_version_code) {
+	struct utsname uts;
+	unsigned x = 0, y = 0, z = 0;	/* cleared in case sscanf() < 3 */
+
+	if (uname(&uts) == -1) /* failure most likely implies impending death */
+	    exit(1);
+
+	if (sscanf(uts.release, "%u.%u.%u", &x, &y, &z) < 3)
+	    fprintf(stderr, /* *very* unlikely to happen by accident */
+		    "Non-standard uts for running kernel:\n"
+		    "release %s=%u.%u.%u gives version code %d\n",
+		    uts.release, x, y, z, LINUX_VERSION_CODE(x,y,z));
+
+	linux_version_code = LINUX_VERSION_CODE(x, y, z);
+    }
+
+    return linux_version_code;
 }
 
 /* ======================================================= */
@@ -63,41 +67,23 @@ glibtop_open_s (glibtop *server, const char *program_name,
 		const unsigned long features,
 		const unsigned flags)
 {
-    char buffer [BUFSIZ], *p;
-    int fd, len, i;
+	char buffer [BUFSIZ], *p = buffer;
 
-    server->name = program_name;
+	server->name = program_name;
 
-    set_linux_version ();
-    server->os_version_code = (unsigned long) linux_version_code;
+	server->os_version_code = get_linux_version();
 
-    server->ncpu = 0;
+	file_to_buffer(server, buffer, FILENAME);
 
-    fd = open (FILENAME, O_RDONLY);
-    if (fd < 0)
-	glibtop_error_io_r (server, "open (%s)", FILENAME);
+	for (server->ncpu = 0; server->ncpu < GLIBTOP_NCPU; server->ncpu++) {
 
-    len = read (fd, buffer, BUFSIZ-1);
-    if (len < 0)
-	glibtop_error_io_r (server, "read (%s)", FILENAME);
+		p = skip_line(p);
 
-    close (fd);
+		if (strncmp (p, "cpu", 3) || !isdigit (p [3]))
+			break;
+	}
 
-    buffer [len] = '\0';
-
-    p = skip_multiple_token (buffer, 5) + 1;
-
-    for (i = 0; i < GLIBTOP_NCPU; i++) {
-		
-	if (strncmp (p, "cpu", 3) || !isdigit (p [3]))
-	    break;
-
-	server->ncpu++;
-
-	p = skip_multiple_token (p, 5) + 1;
-    }
-
-#if DEBUG	
-    printf ("\nThis machine has %d CPUs.\n\n", server->ncpu);
+#ifdef DEBUG
+	printf ("\nThis machine has %d CPUs.\n\n", server->ncpu);
 #endif
 }
