@@ -1,4 +1,4 @@
-/* $Id: open.c,v 1.25 2006/06/24 17:39:49 bdejean Exp $ */
+/* $Id: open.c,v 1.22 2004/10/11 18:01:25 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -21,10 +21,8 @@
    Boston, MA 02111-1307, USA.
 */
 
-#include <config.h>
 #include <glibtop/open.h>
 #include <glibtop/cpu.h>
-#include <glibtop/error.h>
 
 #include <unistd.h>
 #include <dlfcn.h>
@@ -83,8 +81,7 @@ glibtop_get_kstats(glibtop *server)
 	    char cpu[20];
 
 	    for(i = 0, checked = 0; i < GLIBTOP_NCPU || checked == new_ncpu; ++i)
-                if(!server->machine.cpu_stat_kstat[i])
-
+		if(server->machine.cpu_stat_kstat[i])
 		{
 		    sprintf(cpu, "cpu_stat%d", i);
 		    if(!(server->machine.cpu_stat_kstat[i] =
@@ -146,8 +143,6 @@ glibtop_open_s (glibtop *server, const char *program_name,
     for(i = 0; page; ++i, page >>= 1);
     server->machine.pagesize = i - 1;
     server->machine.ticks = sysconf(_SC_CLK_TCK);
-    if(server->machine.kc)
-    	kstat_close(server->machine.kc);
     server->machine.kc = kc = kstat_open ();
 
 #if 0
@@ -213,11 +208,9 @@ glibtop_open_s (glibtop *server, const char *program_name,
 
     /* Now let's have a bit of magic dust... */
 
-#if GLIBTOP_SOLARIS_RELEASE >= 50600
+#if GLIBTOP_SOLARIS_RELEASE >= 560
 
     dl = dlopen("/usr/lib/libproc.so", RTLD_LAZY);
-    if(server->machine.libproc)
-    	dlclose(server->machine.libproc);
     server->machine.libproc = dl;
     if(dl)
     {
@@ -231,7 +224,6 @@ glibtop_open_s (glibtop *server, const char *program_name,
        server->machine.pgrab = (struct ps_prochandle *(*)(pid_t, int, int *))
 	  		       dlsym(dl, "Pgrab");
        server->machine.pfree = (void (*)(void *))dlsym(dl, "Pfree");
-       
     }
     else
     {
