@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: ppp.c,v 1.13 2003/10/19 16:55:49 carlos Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -31,21 +29,16 @@ static const unsigned long _glibtop_sysdeps_ppp = 0;
 
 /* Init function. */
 
-int
+void
 glibtop_init_ppp_s (glibtop *server)
 {
-    server->sysdeps.ppp = _glibtop_sysdeps_ppp;
-
-    return 0;
+	server->sysdeps.ppp = _glibtop_sysdeps_ppp;
 }
 
 /* Provides PPP/ISDN information. */
 
-int
-glibtop_get_ppp_s (glibtop *server, glibtop_ppp *buf, unsigned short device,
-		   unsigned short isdn)
+void
+glibtop_get_ppp_s (glibtop *server, glibtop_ppp *buf, unsigned short device)
 {
-    memset (buf, 0, sizeof (glibtop_ppp));
-
-    return 0;
+	memset (buf, 0, sizeof (glibtop_ppp));
 }
